@@ -6,7 +6,7 @@ from io import BytesIO
 
 from header_rewriter import RewrittenStatusAndHeaders
 
-from rewriterules import RewriteRules, is_lxml
+from rewriterules import RewriteRules
 
 from pywb.utils.dsrules import RuleSet
 from pywb.utils.statusandheaders import StatusAndHeaders
@@ -96,16 +96,15 @@ class RewriteContent:
             else:
                 stream = DecompressingBufferedReader(stream)
 
-        if rewritten_headers.charset:
-            encoding = rewritten_headers.charset
-        elif is_lxml() and text_type == 'html':
-            stream_raw = True
-        else:
-            (encoding, first_buff) = self._detect_charset(stream)
+        #if self.decode_stream:
+        #    if rewritten_headers.charset:
+        #        encoding = rewritten_headers.charset
+        #    else:
+        #        (encoding, first_buff) = self._detect_charset(stream)
 
-        # if encoding not set or chardet thinks its ascii, use utf-8
-        if not encoding or encoding == 'ascii':
-            encoding = 'utf-8'
+            # if encoding not set or chardet thinks its ascii, use utf-8
+        #    if not encoding or encoding == 'ascii':
+        #        encoding = 'utf-8'
 
         rule = self.ruleset.get_first_match(urlkey)
 
@@ -130,35 +129,28 @@ class RewriteContent:
             rewriter = rewriter_class(urlrewriter)
 
         # Create rewriting generator
-        gen = self._rewriting_stream_gen(rewriter, encoding, stream_raw,
+        gen = self._rewriting_stream_gen(rewriter, encoding,
                                          stream, first_buff)
 
         return (status_headers, gen, True)
 
-    def _parse_full_gen(self, rewriter, encoding, stream):
-        buff = rewriter.parse(stream)
-        buff = buff.encode(encoding)
-        yield buff
-
     # Create rewrite stream,  may even be chunked by front-end
-    def _rewriting_stream_gen(self, rewriter, encoding, stream_raw,
+    def _rewriting_stream_gen(self, rewriter, encoding,
                               stream, first_buff=None):
 
-        if stream_raw:
-            return self._parse_full_gen(rewriter, encoding, stream)
-
         def do_rewrite(buff):
-            buff = self._decode_buff(buff, stream, encoding)
-
+            if encoding:
+                buff = self._decode_buff(buff, stream, encoding)
             buff = rewriter.rewrite(buff)
-
-            buff = buff.encode(encoding)
+            if encoding:
+                buff = buff.encode(encoding)
 
             return buff
 
         def do_finish():
             result = rewriter.close()
-            result = result.encode(encoding)
+            if encoding:
+                result = result.encode(encoding)
 
             return result
 
@@ -168,7 +160,7 @@ class RewriteContent:
                                   first_buff=first_buff)
 
     @staticmethod
-    def _decode_buff(buff, stream, encoding):
+    def _decode_buff(buff, stream, encoding): # pragma: no coverage
         try:
             buff = buff.decode(encoding)
         except UnicodeDecodeError, e:
@@ -185,7 +177,7 @@ class RewriteContent:
 
         return buff
 
-    def _detect_charset(self, stream):
+    def _detect_charset(self, stream):  # pragma: no coverage
         full_buff = stream.read(8192)
         io_buff = BytesIO(full_buff)
 
@@ -202,7 +194,7 @@ class RewriteContent:
         finally:
             detector.close()
 
-        print "chardet result: " + str(detector.result)
+        print "chardet result: ", str(detector.result)
         return (detector.result['encoding'], full_buff)
 
     # Create a generator reading from a stream,
